==> webauthn4j-core-0.21.5.RELEASE-sources.jar: com/webauthn4j/validator/DefaultCoreMaliciousCounterValueHandler.java <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.webauthn4j.validator;

import com.webauthn4j.util.AssertUtil;
import com.webauthn4j.validator.exception.MaliciousCounterValueException;
import org.checkerframework.checker.nullness.qual.NonNull;

/**
 * Default implementation of {@link CoreMaliciousCounterValueHandler} that throws {@link MaliciousCounterValueException}
 */
class DefaultCoreMaliciousCounterValueHandler implements CoreMaliciousCounterValueHandler {


    // ~ Methods
    // ========================================================================================================

    @Override
    public void maliciousCounterValueDetected(@NonNull CoreAuthenticationObject authenticationObject) {
        AssertUtil.notNull(authenticationObject, "authenticationObject must not be null");
        throw new MaliciousCounterValueException("Malicious counter value is detected. Cloned authenticators exist in parallel.");
    }
}

==> webauthn4j-core-0.24.0.RELEASE-sources.jar: com/webauthn4j/validator/DefaultCoreMaliciousCounterValueHandler.java <==
/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.webauthn4j.validator;

import com.webauthn4j.util.AssertUtil;
import com.webauthn4j.validator.exception.MaliciousCounterValueException;
import org.jetbrains.annotations.NotNull;

/**
 * Default implementation of {@link CoreMaliciousCounterValueHandler} that throws {@link MaliciousCounterValueException}
 */
class DefaultCoreMaliciousCounterValueHandler implements CoreMaliciousCounterValueHandler {


    // ~ Methods
    // ========================================================================================================

    @Override
    public void maliciousCounterValueDetected(@NotNull CoreAuthenticationObject authenticationObject) {
        AssertUtil.notNull(authenticationObject, "authenticationObject must not be null");
        throw new MaliciousCounterValueException("Malicious counter value is detected. Cloned authenticators exist in parallel.");
    }
}
